@@ -1,8 +1,8 @@
 "dist.list" <-
 function() {
   dist <- c("cau","exp","gam","gev","gld","glo","gno",
-            "gpa","gum","kap","nor","pe3","ray","revgum","wak",
-            "wei");
+            "gpa","gum","kap","kur","ln3","nor","pe3","ray",
+            "revgum","wak","wei");
   return(dist)
 } 
 
